==> vilistextum-2.3.2.tar.gz: vilistextum-v2.3.2/src/html_tag.c <==
/*
 * vilistextum v2.3.2 21.05.01 - a html to text converter
 * Copyright (C) 1998-2001 Patric Mller
 * bhaak@gmx.net
 * http://www.diax.ch/users/bhaak/vilistextum/
 *
 * Released under the GNU GPL - http://www.gnu.org/copyleft/gpl.html
 *
 * 23.04.01 : Ignoring SPAN, /SPAN and /LI
 *            IMG, APPLET, AREA and INPUT are searched for ALT attribute 
 */

#include <ctype.h>
#include <stdio.h>
#include <string.h>

#include "html.h"
#include "text.h"
#include "main.h"
#include "lists.h"
#include "fileio.h"
#include "debug.h"

void html_tag()
{
	char str[DEF_STR_LEN];
  int i=0;

  ch = uppercase(read_char());

  /* Character != '/' bzw '!' and also no letter */
  /* => no HTML-tag */
  if ((!isalpha(ch)) && (ch!='/') && (ch!='!'))
  {
    wort_plus_ch('<');
		goback_char(1);
    //if (ch==' ') { wort_ende(); }
    //else { wort_plus_ch(ch); }
    return;
  }

  while ((ch!='>') && (ch!=' ') && (ch!=13) && (ch!=10))
  {
    str[i++] = ch;
    if (i==DEF_STR_LEN) { fprintf(stderr, "String too long!\n"); quit(); };
    ch = uppercase(read_char());
  }
  str[i] = '\0';
#ifdef debug
  printf("html_tag: %s\n",str);
  status();
#endif

  if (strcmp("/HTML", str)==0) { quit(); }
  else if (strcmp("!DOCTYPE", str)==0) { while ((ch=read_char())!='>'); }

	// Linebreak
  else if (strcmp("BR", str)==0)  { line_break(); }
  else if (strcmp("BR/", str)==0) { line_break(); } // xhtml

  else if (strcmp("P", str)==0)  { start_p(); }
  else if (strcmp("/P", str)==0) { paragraphen_ende(); }
  else if (strcmp("BLOCKQUOTE", str)==0)  { start_p(); }
  else if (strcmp("/BLOCKQUOTE", str)==0) { paragraphen_ende(); }

#ifdef AMIGA
  else if (strcmp("B", str)==0)       { wort_plus_string_nocount("\033[1m");  }
  else if (strcmp("/B", str)==0)      { wort_plus_string_nocount("\033[22m"); }
  else if (strcmp("I", str)==0)       { wort_plus_string_nocount("\033[3m");  }
  else if (strcmp("/I", str)==0)      { wort_plus_string_nocount("\033[23m"); }
  else if (strcmp("U", str)==0)       { wort_plus_string_nocount("\033[4m");  }
  else if (strcmp("/U", str)==0)      { wort_plus_string_nocount("\033[24m"); }
  else if (strcmp("STRONG", str)==0)  { wort_plus_string_nocount("\033[1m");  }
  else if (strcmp("/STRONG", str)==0) { wort_plus_string_nocount("\033[22m"); }
  else if (strcmp("EM", str)==0)      { wort_plus_string_nocount("\033[3m");  }
  else if (strcmp("/EM", str)==0)     { wort_plus_string_nocount("\033[23m"); }
#else
  // Convert these Tags
  else if (strcmp("B", str)==0)       { if (convert_tags) { wort_plus_string("*"); } }
  else if (strcmp("/B", str)==0)      { if (convert_tags) { wort_plus_string("*"); } }
  else if (strcmp("I", str)==0)       { if (convert_tags) { wort_plus_string("/"); } }
  else if (strcmp("/I", str)==0)      { if (convert_tags) { wort_plus_string("/"); } }
  else if (strcmp("U", str)==0)       { if (convert_tags) { wort_plus_string("_"); } }
  else if (strcmp("/U", str)==0)      { if (convert_tags) { wort_plus_string("_"); } }
  else if (strcmp("STRONG", str)==0)  { if (convert_tags) { wort_plus_string("*"); } }
  else if (strcmp("/STRONG", str)==0) { if (convert_tags) { wort_plus_string("*"); } }
  else if (strcmp("EM", str)==0)      { if (convert_tags) { wort_plus_string("/"); } }
  else if (strcmp("/EM", str)==0)     { if (convert_tags) { wort_plus_string("/"); } }
#endif

  else if (strcmp("TITLE", str)==0)  \
	{ 
		if (option_title) { push_align(LEFT); neuer_paragraph(); } 
		else {  wort_ende(); print_zeile(); nooutput = 1; }
	}
  else if (strcmp("/TITLE", str)==0) 
  {
		if (option_title) { paragraphen_ende(); print_zeile(); } 
		else { wort_ende(); print_zeile(); nooutput = 0; }
	}

  // headings
  else if (strcmp("H1", str)==0)  { start_p();          }
  else if (strcmp("/H1", str)==0) { paragraphen_ende(); }
  else if (strcmp("H2", str)==0)  { start_p();          }
  else if (strcmp("/H2", str)==0) { paragraphen_ende(); }
  else if (strcmp("H3", str)==0)  { start_p();          }
  else if (strcmp("/H3", str)==0) { paragraphen_ende(); }
  else if (strcmp("H4", str)==0)  { start_p();          }
  else if (strcmp("/H4", str)==0) { paragraphen_ende(); }
  else if (strcmp("H5", str)==0)  { start_p();          }
  else if (strcmp("/H5", str)==0) { paragraphen_ende(); }
  else if (strcmp("H6", str)==0)  { start_p();          }
  else if (strcmp("/H6", str)==0) { paragraphen_ende(); }

  else if (strcmp("HR", str)==0)  { hr(); }
  else if (strcmp("HR/", str)==0) { hr(); } // xhtml

  else if (strcmp("A", str)==0)   { href(); }

  else if (strcmp("UL", str)==0)  { start_uls(); }
  else if (strcmp("/UL", str)==0) { end_uls(); return; }
  else if (strcmp("LI", str)==0)  { start_lis(); }
  else if (strcmp("OL", str)==0)  { start_ols(); }
  else if (strcmp("/OL", str)==0) { end_ols(); }

  else if (strcmp("DIV", str)==0)      { start_div(0); }
  else if (strcmp("/DIV", str)==0)     { end_div(); }
  else if (strcmp("CENTER", str)==0)   { start_div(CENTER); }
  else if (strcmp("/CENTER", str)==0)  { end_div(); }
  else if (strcmp("RIGHT", str)==0)    { start_div(RIGHT); }
  else if (strcmp("/RIGHT", str)==0)   { end_div(); }

	// tags with alt attribute
  else if (strcmp("IMG", str)==0)    { image(default_image, 1); }
  else if (strcmp("APPLET", str)==0) { image("Applet", 1); }
  else if (strcmp("AREA", str)==0)   { image("Area", 0); }
  else if (strcmp("INPUT", str)==0)  { image("Input", 0); }

	// table
  else if (strcmp("TABLE", str)==0)    { /*start_p();*/ push_align(LEFT); neuer_paragraph(); }
  else if (strcmp("/TABLE", str)==0)   { paragraphen_ende(); }
  else if (strcmp("TD", str)==0)       { wort_plus_ch(' '); }
  else if (strcmp("/TD", str)==0)      {}
  else if (strcmp("TH", str)==0)       {}
  else if (strcmp("/TH", str)==0)      {}
  else if (strcmp("TR", str)==0)       { line_break(); } // start_p(); 
  else if (strcmp("/TR", str)==0)      { /*paragraphen_ende();*/ }
  else if (strcmp("CAPTION", str)==0)  {}
  else if (strcmp("/CAPTION", str)==0) {}

  else if (strcmp("PRE", str)==0)   { start_p();  pre=1; }
  else if (strcmp("/PRE", str)==0)  { paragraphen_ende(); pre=0; }

  else if (strcmp("DL", str)==0)  { start_dl();} // Definition List
  else if (strcmp("/DL", str)==0) { end_dl(); }
  else if (strcmp("DT", str)==0)  { start_dt(); } // Definition Title
  else if (strcmp("/DT", str)==0) { end_dt(); }
  else if (strcmp("DD", str)==0)  { start_dd(); } // Definition Description
  else if (strcmp("/DD", str)==0) { end_dd(); }

  else if (strcmp("SCRIPT", str)==0)  { wort_ende(); print_zeile(); nooutput = 1; }
  else if (strcmp("/SCRIPT", str)==0) { wort_ende(); print_zeile(); nooutput = 0; }
  else if (strcmp("STYLE", str)==0)   { wort_ende(); print_zeile(); nooutput = 1; }
  else if (strcmp("/STYLE", str)==0)  { wort_ende(); print_zeile(); nooutput = 0; }

  // those tags are ignored
  else if (strcmp("HTML", str)==0)      {}
  else if (strcmp("BASE", str)==0)      {}
  else if (strcmp("LINK", str)==0)      {}
  else if (strcmp("BASEFONT", str)==0)  {}
  else if (strcmp("META", str)==0)      {}

  else if (strcmp("HEAD", str)==0)      {}
  else if (strcmp("/HEAD", str)==0)     {}
  else if (strcmp("BODY", str)==0)      {}
  else if (strcmp("/BODY", str)==0)     {}
  else if (strcmp("FONT", str)==0)      {}
  else if (strcmp("/FONT", str)==0)     {}
  else if (strcmp("SAMP", str)==0)      {}
  else if (strcmp("/SAMP", str)==0)     {}
  else if (strcmp("CODE", str)==0)      {}
  else if (strcmp("/CODE", str)==0)     {}
  else if (strcmp("MAP", str)==0)       {}
  else if (strcmp("/MAP", str)==0)      {}
  else if (strcmp("SUP", str)==0)       {}
  else if (strcmp("/SUP", str)==0)      {}
  else if (strcmp("FORM", str)==0)      {}
  else if (strcmp("/FORM", str)==0)     {}
  else if (strcmp("ADDRESS", str)==0)   {}
  else if (strcmp("/ADDRESS", str)==0)  {}
	else if (strcmp("TT", str)==0)        {}
	else if (strcmp("/TT", str)==0)       {}
  else if (strcmp("SUB", str)==0)       {}
  else if (strcmp("/SUB", str)==0)      {}
  else if (strcmp("NOSCRIPT", str)==0)  {}
  else if (strcmp("/NOSCRIPT", str)==0) {}
  else if (strcmp("SMALL", str)==0)     {}
  else if (strcmp("/SMALL", str)==0)    {}
  else if (strcmp("SPAN", str)==0)      {}
  else if (strcmp("/SPAN", str)==0)     {}

	else if (strcmp("/AREA", str)==0)     {}
  else if (strcmp("/LI", str)==0)       {}
  else if (strcmp("/A", str)==0)        {}
    
  else if (strncmp("!--", str, 3)==0)  { friss_kommentar(); } // Comment

  else { if (errorlevel>=2) { fprintf(stderr, "tag %s ignored!\n", str);} }

	//	printf("ch1: %c\n", ch);

  // Skip attributes
  while (ch!='>')
  {
#ifdef debug
    printf("char %c\n", ch);
#endif
    ch = get_attr();
		
#ifdef debug
    printf("char2 %c\n", ch);
		printf("Attribut: %c;\n", *attr_name); 
		printf("Attribut: %c;\n", attr_name[1]); 
		printf("Attribut: %c;\n", attr_name[2]); 
		printf("Attribut: %c;\n", attr_name[3]); 
		printf("Attribut: %c;\n", attr_name[4]); 
		printf("Attribut: %c;\n", attr_name[5]); 

		printf("Attribut: %s;\n", attr_name); 
		printf("Inhalt: %s#\n", attr_ctnt);
#endif
  }
	//	printf("\nch2: %c\n", ch);
} // end html_tag

==> vilistextum-2.4.1.tar.gz: vilistextum-2.4.1/src/html_tag.c <==
/*
 * Copyright (C) 1998-2001 Patric Mller
 * bhaak@gmx.net
 * http://www.diax.ch/users/bhaak/vilistextum/
 *
 * Released under the GNU GPL - http://www.gnu.org/copyleft/gpl.html
 *
 * 23.04.01 : Ignoring SPAN, /SPAN and /LI
 *            IMG, APPLET, AREA and INPUT are searched for ALT attribute 
 * 13.08.01 : Ignoring DFN and /DFN
 * 24.08.01 : Fixed Frisskommentar
 * 02.09.01 : Ignoring BLINK, /BLINK, CITE and /CITE
 *
 */

#include <ctype.h>
#include <stdio.h>
#include <string.h>

#include "html.h"
#include "text.h"
#include "main.h"
#include "lists.h"
#include "fileio.h"
#include "debug.h"

void html_tag()
{
	char str[DEF_STR_LEN];
  int i=0;

  ch = uppercase(read_char());

  /* Character != '/' bzw '!' and also no letter */
  /* => no HTML-tag */
  if ((!isalpha(ch)) && (ch!='/') && (ch!='!'))
  {
    wort_plus_ch('<');
		goback_char(1);
    //if (ch==' ') { wort_ende(); }
    //else { wort_plus_ch(ch); }
    return;
  }

  while ((ch!='>') && (ch!=' ') && (ch!=13) && (ch!=10))
  {
    str[i++] = ch;
    if (i==DEF_STR_LEN) { fprintf(stderr, "String too long!\n"); quit(); };
    ch = uppercase(read_char());
  }
  str[i] = '\0';
#ifdef debug
  printf("html_tag: %s\n",str);
  status();
#endif

  if (strcmp("/HTML", str)==0) { quit(); }
  else if (strcmp("!DOCTYPE", str)==0) { while ((ch=read_char())!='>'); }

	// Linebreak
  else if (strcmp("BR", str)==0)  { line_break(); }
  else if (strcmp("BR/", str)==0) { line_break(); } // xhtml

  else if (strcmp("P", str)==0)  { start_p(); }
  else if (strcmp("/P", str)==0) { paragraphen_ende(); }
  else if (strcmp("BLOCKQUOTE", str)==0)  { start_p(); }
  else if (strcmp("/BLOCKQUOTE", str)==0) { paragraphen_ende(); }

#ifdef AMIGA
  else if (strcmp("B", str)==0)       { wort_plus_string_nocount("\033[1m");  }
  else if (strcmp("/B", str)==0)      { wort_plus_string_nocount("\033[22m"); }
  else if (strcmp("I", str)==0)       { wort_plus_string_nocount("\033[3m");  }
  else if (strcmp("/I", str)==0)      { wort_plus_string_nocount("\033[23m"); }
  else if (strcmp("U", str)==0)       { wort_plus_string_nocount("\033[4m");  }
  else if (strcmp("/U", str)==0)      { wort_plus_string_nocount("\033[24m"); }
  else if (strcmp("STRONG", str)==0)  { wort_plus_string_nocount("\033[1m");  }
  else if (strcmp("/STRONG", str)==0) { wort_plus_string_nocount("\033[22m"); }
  else if (strcmp("EM", str)==0)      { wort_plus_string_nocount("\033[3m");  }
  else if (strcmp("/EM", str)==0)     { wort_plus_string_nocount("\033[23m"); }
#else
  // Convert these Tags
  else if (strcmp("B", str)==0)       { if (convert_tags) { wort_plus_string("*"); } }
  else if (strcmp("/B", str)==0)      { if (convert_tags) { wort_plus_string("*"); } }
  else if (strcmp("I", str)==0)       { if (convert_tags) { wort_plus_string("/"); } }
  else if (strcmp("/I", str)==0)      { if (convert_tags) { wort_plus_string("/"); } }
  else if (strcmp("U", str)==0)       { if (convert_tags) { wort_plus_string("_"); } }
  else if (strcmp("/U", str)==0)      { if (convert_tags) { wort_plus_string("_"); } }
  else if (strcmp("STRONG", str)==0)  { if (convert_tags) { wort_plus_string("*"); } }
  else if (strcmp("/STRONG", str)==0) { if (convert_tags) { wort_plus_string("*"); } }
  else if (strcmp("EM", str)==0)      { if (convert_tags) { wort_plus_string("/"); } }
  else if (strcmp("/EM", str)==0)     { if (convert_tags) { wort_plus_string("/"); } }
#endif

  else if (strcmp("TITLE", str)==0)  \
	{ 
		if (option_title) { push_align(LEFT); neuer_paragraph(); } 
		else {  wort_ende(); print_zeile(); nooutput = 1; }
	}
  else if (strcmp("/TITLE", str)==0) 
  {
		if (option_title) { paragraphen_ende(); print_zeile(); } 
		else { wort_ende(); print_zeile(); nooutput = 0; }
	}

  // headings
  else if (strcmp("H1", str)==0)  { start_p();          }
  else if (strcmp("/H1", str)==0) { paragraphen_ende(); }
  else if (strcmp("H2", str)==0)  { start_p();          }
  else if (strcmp("/H2", str)==0) { paragraphen_ende(); }
  else if (strcmp("H3", str)==0)  { start_p();          }
  else if (strcmp("/H3", str)==0) { paragraphen_ende(); }
  else if (strcmp("H4", str)==0)  { start_p();          }
  else if (strcmp("/H4", str)==0) { paragraphen_ende(); }
  else if (strcmp("H5", str)==0)  { start_p();          }
  else if (strcmp("/H5", str)==0) { paragraphen_ende(); }
  else if (strcmp("H6", str)==0)  { start_p();          }
  else if (strcmp("/H6", str)==0) { paragraphen_ende(); }

  else if (strcmp("HR", str)==0)  { hr(); }
  else if (strcmp("HR/", str)==0) { hr(); } // xhtml

  else if (strcmp("A", str)==0)   { href(); }

  else if (strcmp("UL", str)==0)  { start_uls(); }
  else if (strcmp("/UL", str)==0) { end_uls(); return; }
  else if (strcmp("LI", str)==0)  { start_lis(); }
  else if (strcmp("OL", str)==0)  { start_ols(); }
  else if (strcmp("/OL", str)==0) { end_ols(); }

  else if (strcmp("DIV", str)==0)      { start_div(0); }
  else if (strcmp("/DIV", str)==0)     { end_div(); }
  else if (strcmp("CENTER", str)==0)   { start_div(CENTER); }
  else if (strcmp("/CENTER", str)==0)  { end_div(); }
  else if (strcmp("RIGHT", str)==0)    { start_div(RIGHT); }
  else if (strcmp("/RIGHT", str)==0)   { end_div(); }

	// tags with alt attribute
  else if (strcmp("IMG", str)==0)    { image(default_image, 1); }
  else if (strcmp("APPLET", str)==0) { image("Applet", 1); }
  else if (strcmp("AREA", str)==0)   { image("Area", 0); }
  else if (strcmp("INPUT", str)==0)  { image("Input", 0); }

	// table
  else if (strcmp("TABLE", str)==0)    { /*start_p();*/ push_align(LEFT); neuer_paragraph(); }
  else if (strcmp("/TABLE", str)==0)   { paragraphen_ende(); }
  else if (strcmp("TD", str)==0)       { wort_plus_ch(' '); }
  else if (strcmp("/TD", str)==0)      {}
  else if (strcmp("TH", str)==0)       {}
  else if (strcmp("/TH", str)==0)      {}
  else if (strcmp("TR", str)==0)       { line_break(); } // start_p(); 
  else if (strcmp("/TR", str)==0)      { /*paragraphen_ende();*/ }
  else if (strcmp("CAPTION", str)==0)  {}
  else if (strcmp("/CAPTION", str)==0) {}

  else if (strcmp("PRE", str)==0)   { start_p();  pre=1; }
  else if (strcmp("/PRE", str)==0)  { paragraphen_ende(); pre=0; }

  else if (strcmp("DL", str)==0)  { start_dl();} // Definition List
  else if (strcmp("/DL", str)==0) { end_dl(); }
  else if (strcmp("DT", str)==0)  { start_dt(); } // Definition Title
  else if (strcmp("/DT", str)==0) { end_dt(); }
  else if (strcmp("DD", str)==0)  { start_dd(); } // Definition Description
  else if (strcmp("/DD", str)==0) { end_dd(); }

  else if (strcmp("SCRIPT", str)==0)  { wort_ende(); print_zeile(); nooutput = 1; }
  else if (strcmp("/SCRIPT", str)==0) { wort_ende(); print_zeile(); nooutput = 0; }
  else if (strcmp("STYLE", str)==0)   { wort_ende(); print_zeile(); nooutput = 1; }
  else if (strcmp("/STYLE", str)==0)  { wort_ende(); print_zeile(); nooutput = 0; }

  // those tags are ignored
  else if (strcmp("HTML", str)==0)      {}
  else if (strcmp("BASE", str)==0)      {}
  else if (strcmp("LINK", str)==0)      {}
  else if (strcmp("BASEFONT", str)==0)  {}
  else if (strcmp("META", str)==0)      {}

  else if (strcmp("HEAD", str)==0)      {}
  else if (strcmp("/HEAD", str)==0)     {}
  else if (strcmp("BODY", str)==0)      {}
  else if (strcmp("/BODY", str)==0)     {}
  else if (strcmp("FONT", str)==0)      {}
  else if (strcmp("/FONT", str)==0)     {}
  else if (strcmp("SAMP", str)==0)      {}
  else if (strcmp("/SAMP", str)==0)     {}
  else if (strcmp("CODE", str)==0)      {}
  else if (strcmp("/CODE", str)==0)     {}
  else if (strcmp("MAP", str)==0)       {}
  else if (strcmp("/MAP", str)==0)      {}
  else if (strcmp("SUP", str)==0)       {}
  else if (strcmp("/SUP", str)==0)      {}
  else if (strcmp("FORM", str)==0)      {}
  else if (strcmp("/FORM", str)==0)     {}
  else if (strcmp("ADDRESS", str)==0)   {}
  else if (strcmp("/ADDRESS", str)==0)  {}
  else if (strcmp("TT", str)==0)        {}
  else if (strcmp("/TT", str)==0)       {}
  else if (strcmp("SUB", str)==0)       {}
  else if (strcmp("/SUB", str)==0)      {}
  else if (strcmp("NOSCRIPT", str)==0)  {}
  else if (strcmp("/NOSCRIPT", str)==0) {}
  else if (strcmp("SMALL", str)==0)     {}
  else if (strcmp("/SMALL", str)==0)    {}
  else if (strcmp("SPAN", str)==0)      {}
  else if (strcmp("/SPAN", str)==0)     {}
  else if (strcmp("DFN", str)==0)       {}
  else if (strcmp("/DFN", str)==0)      {}
  else if (strcmp("BLINK", str)==0)     {}
  else if (strcmp("/BLINK", str)==0)    {}
  else if (strcmp("CITE", str)==0)      {}
  else if (strcmp("/CITE", str)==0)     {}

  else if (strcmp("/AREA", str)==0)     {}
  else if (strcmp("/LI", str)==0)       {}
  else if (strcmp("/A", str)==0)        {}
    
  else if (strncmp("!--", str, 3)==0)  { 
#ifdef debug
					printf("Frisskommentar %s\n", str);
#endif 
					goback_char(3);
					friss_kommentar(); 
					goback_char(1);
					ch = read_char();
} // Comment

  else { if (errorlevel>=2) { fprintf(stderr, "tag %s ignored!\n", str);} }

	// printf("ch1: %c\n", ch);

  // Skip attributes
  while (ch!='>')
  {
#ifdef debug
    printf("char %c\n", ch);
#endif
    ch = get_attr();
		
#ifdef debug
    printf("char2 %c\n", ch);
		printf("Attribut: %c;\n", *attr_name); 
		printf("Attribut: %c;\n", attr_name[1]); 
		printf("Attribut: %c;\n", attr_name[2]); 
		printf("Attribut: %c;\n", attr_name[3]); 
		printf("Attribut: %c;\n", attr_name[4]); 
		printf("Attribut: %c;\n", attr_name[5]); 

		printf("Attribut: %s;\n", attr_name); 
		printf("Inhalt: %s#\n", attr_ctnt);
#endif
  }
	//	printf("\nch2: %c\n", ch);
} // end html_tag
